
/////////////////////////////////////////////////////////////
//
// Source file for FormUI
//
//    This class implements the user interface created in 
//    the interface builder. Normally it is not used directly.
//    Instead the subclass, Form is instantiated
//
//    To extend or alter the behavior of this class, you should
//    modify the Form files
//
//    Restrict changes to those sections between
//    the "//--- Start/End editable code block" markers
//
//    This will allow the builder to integrate changes more easily
//
//    This class is a ViewKit user interface "component".
//    For more information on how components are used, see the
//    "ViewKit Programmers' Manual", and the RapidApp
//    User's Guide.
//
//
/////////////////////////////////////////////////////////////


#include "FormUI.h" // Generated header file for this class

#include <Xm/Form.h> 
#include <Xm/Label.h> 
#include <Xm/PushB.h> 
#include <Xm/TextF.h> 
#include <Vk/VkResource.h>
//---- Start editable code block: headers and declarations


//---- End editable code block: headers and declarations



// These are default resources for widgets in objects of this class
// All resources will be prepended by *<name> at instantiation,
// where <name> is the name of the specific instance, as well as the
// name of the baseWidget. These are only defaults, and may be overriden
// in a resource file by providing a more specific resource name

String  FormUI::_defaultFormUIResources[] = {
        "*label.labelString:  User host name:",
        "*cancelButton.labelString:  Cancel",
        "*callButton.labelString:  Call",
        (char*)NULL
};

FormUI::FormUI(const char *name) : VkComponent(name) 
{ 
    // No widgets are created by this constructor.
    // If an application creates a component using this constructor,
    // It must explictly call create at a later time.
    // This is mostly useful when adding pre-widget creation
    // code to a derived class constructor.

    //---- Start editable code block: Form constructor 2


    //---- End editable code block: Form constructor 2


} // End Constructor




FormUI::FormUI(const char *name, Widget parent) : VkComponent(name) 
{ 
    // Call creation function to build the widget tree.

     create(parent);

    //---- Start editable code block: Form constructor


    //---- End editable code block: Form constructor


} // End Constructor


FormUI::~FormUI() 
{
    // Base class destroys widgets

    //---- Start editable code block: FormUI destructor


    //---- End editable code block: FormUI destructor
} // End destructor



void FormUI::create ( Widget parent )
{
    Arg      args[14];
    Cardinal count;
    count = 0;

    // Load any class-defaulted resources for this object

    setDefaultResources(parent, _defaultFormUIResources  );


    // Create an unmanaged widget as the top of the widget hierarchy

    _baseWidget = _form = XtVaCreateWidget ( _name,
                                             xmFormWidgetClass,
                                             parent, 
                                             XmNresizePolicy, XmRESIZE_GROW, 
                                             (XtPointer) NULL ); 

    // install a callback to guard against unexpected widget destruction

    installDestroyHandler();


    // Create widgets used in this component
    // All variables are data members of this class

    _label = XtVaCreateManagedWidget  ( "label",
                                         xmLabelWidgetClass,
                                         _baseWidget, 
                                         XmNlabelType, XmSTRING, 
                                         XmNtopAttachment, XmATTACH_FORM, 
                                         XmNbottomAttachment, XmATTACH_NONE, 
                                         XmNleftAttachment, XmATTACH_FORM, 
                                         XmNrightAttachment, XmATTACH_NONE, 
                                         XmNtopOffset, 15, 
                                         XmNbottomOffset, 0, 
                                         XmNleftOffset, 20, 
                                         XmNrightOffset, 0, 
                                         XmNwidth, 118, 
                                         XmNheight, 20, 
                                         (XtPointer) NULL ); 


    _cancelButton = XtVaCreateManagedWidget  ( "cancelButton",
                                                xmPushButtonWidgetClass,
                                                _baseWidget, 
                                                XmNlabelType, XmSTRING, 
                                                XmNrecomputeSize, False, 
                                                XmNtopAttachment, XmATTACH_FORM, 
                                                XmNbottomAttachment, XmATTACH_NONE, 
                                                XmNleftAttachment, XmATTACH_FORM, 
                                                XmNrightAttachment, XmATTACH_NONE, 
                                                XmNtopOffset, 55, 
                                                XmNbottomOffset, 0, 
                                                XmNleftOffset, 170, 
                                                XmNrightOffset, 0, 
                                                XmNwidth, 100, 
                                                XmNheight, 35, 
                                                (XtPointer) NULL ); 

    XtAddCallback ( _cancelButton,
                    XmNactivateCallback,
                    &FormUI::cancelCallback,
                    (XtPointer) this ); 


    _callButton = XtVaCreateManagedWidget  ( "callButton",
                                              xmPushButtonWidgetClass,
                                              _baseWidget, 
                                              XmNlabelType, XmSTRING, 
                                              XmNrecomputeSize, False, 
                                              XmNtopAttachment, XmATTACH_FORM, 
                                              XmNbottomAttachment, XmATTACH_NONE, 
                                              XmNleftAttachment, XmATTACH_FORM, 
                                              XmNrightAttachment, XmATTACH_FORM, 
                                              XmNrightPosition, 0, 
                                              XmNtopOffset, 55, 
                                              XmNbottomOffset, 0, 
                                              XmNleftOffset, 70, 
                                              XmNrightOffset, 189, 
                                              XmNwidth, 100, 
                                              XmNheight, 35, 
                                              (XtPointer) NULL ); 

    XtAddCallback ( _callButton,
                    XmNactivateCallback,
                    &FormUI::callCallback,
                    (XtPointer) this ); 


    _hostTextField = XtVaCreateManagedWidget  ( "hostTextField",
                                                 xmTextFieldWidgetClass,
                                                 _baseWidget, 
                                                 XmNtopAttachment, XmATTACH_FORM, 
                                                 XmNbottomAttachment, XmATTACH_NONE, 
                                                 XmNleftAttachment, XmATTACH_FORM, 
                                                 XmNrightAttachment, XmATTACH_NONE, 
                                                 XmNtopOffset, 10, 
                                                 XmNbottomOffset, 0, 
                                                 XmNleftOffset, 145, 
                                                 XmNrightOffset, 0, 
                                                 XmNwidth, 200, 
                                                 XmNheight, 35, 
                                                 (XtPointer) NULL ); 


    //---- Start editable code block: FormUI create


    //---- End editable code block: FormUI create
}

const char * FormUI::className()
{
    return ("FormUI");
} // End className()




/////////////////////////////////////////////////////////////// 
// The following functions are static member functions used to 
// interface with Motif.
/////////////////////////////////// 

void FormUI::callCallback ( Widget    w,
                            XtPointer clientData,
                            XtPointer callData ) 
{ 
    FormUI* obj = ( FormUI * ) clientData;
    obj->call ( w, callData );
}

void FormUI::cancelCallback ( Widget    w,
                              XtPointer clientData,
                              XtPointer callData ) 
{ 
    FormUI* obj = ( FormUI * ) clientData;
    obj->cancel ( w, callData );
}



/////////////////////////////////////////////////////////////// 
// The following functions are called from the menu items 
// in this window.
/////////////////////////////////// 

void FormUI::call ( Widget, XtPointer ) 
{
    // This virtual function is called from callCallback.
    // This function is normally overriden by a derived class.

}

void FormUI::cancel ( Widget, XtPointer ) 
{
    // This virtual function is called from cancelCallback.
    // This function is normally overriden by a derived class.

}



